<div align="center">
<a href="https://llmkira.github.io/Docs/plugin/basic">
    <img src="https://raw.githubusercontent.com/LlmKira/.github/main/llmbot/func_call_big.png">
</a>
<h2>llmbot-plugin-sticker</h2>
</div>

适用于 [OpenaiBot](https://github.com/LlmKira/Openaibot) 的函数插件，贴纸。

## 📦 Install

```shell
pip install llmbot_plugin_sticker -U
```

### 📝 美术资源许可注意

1.0.* 版本的美术资源仅供测试使用，不可用于商业用途。版权归原作者所有。

## 📝 Hook

https://github.com/LlmKira/llmbot_plugin_sticker/blob/a699c2c726ae8c8a2e1e5acbdfb671a7e37966ba/llmbot_plugin_sticker/__init__.py#L74-L99